[PATCH] rombios: set int vector 77h and below to dummy iret handler

"Sebastian Herbszt" <[email protected]>
Newsgroups gmane.comp.emulators.bochs.devel
Message-ID <E6ED55EE1F60478AA43B90B8F034BA32@FSCPC>
Set INT vector 77h and below to dummy iret handler.
Change based on sf patch #507.

Sebastian

Index: bios/rombios.c
===================================================================
--- bios.orig/rombios.c
+++ bios/rombios.c
@@ -10679,9 +10679,9 @@ post_init_pic:
   ret
 
 post_init_ivt:
   ;; set all interrupts to default handler
   xor  di, di         ;; offset index
-  mov  cx, #0x0100    ;; counter (256 interrupts)
+  mov  cx, #0x0078    ;; counter (120 interrupts)
   mov  ax, #0xF000
   shl  eax, #16
   mov  ax, #dummy_iret_handler

------------------------------------------------------------------------------
@@ -10679,9 +10679,9 @@ post_init_pic:
 
 post_init_ivt:
-  ;; set all interrupts to default handler
+  ;; set first 120 interrupts to default handler
   xor  di, di         ;; offset index
Master Visual Studio, SharePoint, SQL, ASP.NET, C# 2012, HTML5, CSS,
MVC, Windows 8 Apps, JavaScript and much more. Keep your skills current
with LearnDevNow - 3,200 step-by-step video tutorials by Microsoft
MVPs and experts. ON SALE this month only -- learn more at:
http://p.sf.net/sfu/learnmore_123012

_______________________________________________
bochs-developers mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/bochs-developers
set_int_77h_and_below_to_dummy_iret_handler.diff (application/octet-stream, 501 B)
Index: bios/rombios.c
===================================================================
--- bios.orig/rombios.c
+++ bios/rombios.c
@@ -10679,9 +10679,9 @@ post_init_pic:
   ret
 
 post_init_ivt:
   ;; set all interrupts to default handler
   xor  di, di         ;; offset index
-  mov  cx, #0x0100    ;; counter (256 interrupts)
+  mov  cx, #0x0078    ;; counter (120 interrupts)
   mov  ax, #0xF000
   shl  eax, #16
   mov  ax, #dummy_iret_handler
@@ -10679,9 +10679,9 @@ post_init_pic:
 
 post_init_ivt:
-  ;; set all interrupts to default handler
+  ;; set first 120 interrupts to default handler
   xor  di, di         ;; offset index
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.